@@ -249,7 +249,7 @@ make_path_spline (GogChartMap *map,
 	is_inverted = gog_axis_map_is_inverted (map->axis_map[1]);
 
 	n_valid_points = 0;
-	for (i = 0; i <= n_points; i++) {
+	for (i = 0; i < n_points; i++) {
 		yy = y != NULL ? y[i] : i + 1;
 		if (is_polar) {
 			if (is_inverted && yy > yy_max)
@@ -263,8 +263,7 @@ make_path_spline (GogChartMap *map,
 		if (go_finite (u)
 		    && go_finite (v)
 		    && fabs (u) != DBL_MAX
-		    && fabs (v) != DBL_MAX
-		    && i != n_points) {
+		    && fabs (v) != DBL_MAX) {
 			n_valid_points++;
 
 			ii = i % 3;
@@ -324,6 +323,15 @@ make_path_spline (GogChartMap *map,
 		}
 	}
 
+	if (n_valid_points == 2)
+		go_path_line_to (path, uu[ii], vv[ii]);
+	else if (n_valid_points > 2)
+		go_path_curve_to (path,
+				  uu[ii_prev] + lengths[ii] * cos (thetas[ii]),
+				  vv[ii_prev] + lengths[ii] * sin (thetas[ii]),
+				  uu[ii], vv[ii],
+				  uu[ii], vv[ii]);
+
 	return path;
 }
 
@@ -682,6 +690,9 @@ gog_chart_map_new (GogChart *chart, GogViewAllocation const *area,
 	GogAxisSet axis_set;
 
 	g_return_val_if_fail (IS_GOG_CHART (chart), NULL);
+	axis_set = gog_chart_get_axis_set (chart);
+	g_return_val_if_fail (axis_set != GOG_AXIS_SET_UNKNOWN &&
+			      axis_set != GOG_AXIS_SET_NONE, NULL);
 
 	map = g_new (GogChartMap, 1);
 
@@ -690,15 +701,14 @@ gog_chart_map_new (GogChart *chart, GogViewAllocation const *area,
 	map->area = *area;
 	map->data = NULL;
 	map->is_valid = FALSE;
+	map->axis_map[0] = map->axis_map[1] = map->axis_map[2] = NULL;
 
-	axis_set = gog_chart_get_axis_set (chart);
 	switch (axis_set & GOG_AXIS_SET_FUNDAMENTAL) {
 		case GOG_AXIS_SET_X:
 			{
 				XMapData *data = g_new (XMapData, 1);
 
 				map->axis_map[0] = gog_axis_map_new (axis0, map->area.x, map->area.w);
-				map->axis_map[1] = map->axis_map[2] = NULL;
 
 				data->b = area->y + area->h;
 				data->a = - area->h;
@@ -718,7 +728,6 @@ gog_chart_map_new (GogChart *chart, GogViewAllocation const *area,
 				map->axis_map[0] = gog_axis_map_new (axis0, map->area.x, map->area.w);
 				map->axis_map[1] = gog_axis_map_new (axis1, map->area.y + map->area.h,
 								     -map->area.h);
-				map->axis_map[2] = NULL;
 
 				map->data = NULL;
 				map->map_2D_to_view = xy_map_2D_to_view;
@@ -758,7 +767,6 @@ gog_chart_map_new (GogChart *chart, GogViewAllocation const *area,
 									     minimum - maximum);
 				}
 				map->axis_map[1] = gog_axis_map_new (axis1, 0.0, 1.0);
-				map->axis_map[2] = NULL;
 
 				map->data = data;
 				map->map_2D_to_view = polar_map_2D_to_view;
@@ -769,13 +777,8 @@ gog_chart_map_new (GogChart *chart, GogViewAllocation const *area,
 					gog_axis_map_is_valid (map->axis_map[1]);
 				break;
 			}
-		case GOG_AXIS_SET_XYZ:
-		case GOG_AXIS_SET_ALL:
-		case GOG_AXIS_SET_NONE:
-		case GOG_AXIS_SET_UNKNOWN:
 		default:
-			g_warning ("[Chart::map_new] not implemented for this axis set (%i)",
-				   axis_set);
+			g_warning ("[GogChartMap::new] unimplemented for axis set %d", axis_set);
 			map->map_2D_to_view = null_map_2D;
 			break;
 	}
