@@ -185,6 +185,18 @@ go_glade_signal_connect_swapped (GladeXML	*gui,
 	return g_signal_connect_swapped (w, detailed_signal, c_handler, data);
 }
 
+
+/*
+ * A variant of gtk_window_activate_default that does not end up reactivating
+ * the widget that [Enter] was pressed in.
+ */
+static void
+cb_activate_default (GtkWindow *window)
+{
+	if (window->default_widget && GTK_WIDGET_IS_SENSITIVE (window->default_widget))
+		gtk_widget_activate (window->default_widget);
+}
+
 /**
  * go_gtk_editable_enters:
  * @window:
@@ -202,7 +214,7 @@ go_gtk_editable_enters (GtkWindow *window, GtkWidget *w)
 	g_return_if_fail (GTK_IS_WINDOW (window));
 	g_signal_connect_swapped (G_OBJECT (w),
 		"activate",
-		G_CALLBACK (gtk_window_activate_default), window);
+		G_CALLBACK (cb_activate_default), window);
 }
 
 void
@@ -740,9 +752,7 @@ typedef struct {
 static void
 go_help_display (CBHelpPaths const *paths)
 {
-#ifdef GOFFICE_WITH_GNOME
-	gnome_help_display (paths->app, paths->link, NULL);
-#elif defined(G_OS_WIN32)
+#if defined(G_OS_WIN32)
 	static GHashTable* context_help_map = NULL;
 	guint id;
 
@@ -796,6 +806,12 @@ go_help_display (CBHelpPaths const *paths)
 		g_free (path);
 	}
 #else
+#ifdef GOFFICE_WITH_GNOME
+	if (gnome_program_get () != NULL) {
+		gnome_help_display (paths->app, paths->link, NULL);
+		return;
+	}
+#endif
 	go_gtk_notice_dialog (NULL, GTK_MESSAGE_ERROR,
 			      "TODO : launch help browser for %s", paths->link);
 #endif
